[KSplash Theme: joy]
Name = Joy Splash Screen
Description = Debian Joy Splash Screen, with both 4:3 and 16:9, based largely on work by the authors listed...
Version = 1.0
Author = Adrien Aubourg <adrien.aubourg@gmail.com>, Eshat Cakar <info@eshat.de>, Nuno Pinheiro <nuno@oxygen-icons.org>, Riccardo Iaconelli <riccardo@kde.org>
Homepage = http://wiki.debian.org/DebianArt/Themes/Joy

# Theme behaviour settings.
Engine = KSplashX
